@@ -88,12 +88,13 @@ def scale_down_imgfile(imgfile, factor):
 def cap_dimensions(width, height, max_pixels):
     "https://stackoverflow.com/questions/10106792/resize-image-by-pixel-amount"
     pixels = width * height
-    if pixels <= max_pixels:
+    if (pixels <= max_pixels):
         return (width, height)
+
     ratio = float(width) / height
-    scale = (float(pixels) / max_pixels) ** (width / (height * 2))
-    height2 = round(float(height) / scale)
-    width2 = round(ratio * height2)
+    scale = math.sqrt(float(pixels) / max_pixels)
+    height2 = int(float(height) / scale)
+    width2 = int(ratio * height / scale)
     return (width2, height2)
 
 
